<?php

declare(strict_types=1);

namespace Drupal\node_menu_placer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Node Menu Placer settings for this site.
 */
final class ConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'node_menu_placer_config';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['node_menu_placer.config'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['no_link_placement'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Allow placement under &lt;nolink&gt; menu items'),
      '#default_value' => $this->config('node_menu_placer.config')->get('no_link_placement') ?? TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('node_menu_placer.config')
      ->set('no_link_placement', $form_state->getValue('no_link_placement'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
